# Generated by Django 3.1 on 2021-02-23 15:24
from django.db import migrations, models

import pymess.models.emails


class Migration(migrations.Migration):

    dependencies = [
        ('pymess', '0022_migration'),
    ]

    operations = [
        migrations.AddField(
            model_name='emailmessage',
            name='content_file',
            field=models.FileField(blank=True, null=True, upload_to=pymess.models.emails.generate_content_filename,
                                   verbose_name='content file'),
        ),
        migrations.AlterField(
            model_name='emailmessage',
            name='content',
            field=models.TextField(verbose_name='content', null=True, blank=True)
        ),
        migrations.RenameField(
            model_name='emailmessage',
            old_name='content',
            new_name='old_content',
        ),
        migrations.AlterField(
            model_name='attachment',
            name='file',
            field=models.FileField(upload_to=pymess.models.emails.generate_attachment_filename,
                                   verbose_name='file'),
        ),
    ]
