# Generated by Django 3.1 on 2021-12-31 10:25

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('pymess', '0026_migration'),
    ]

    operations = [
        migrations.AddField(
            model_name='pushnotificationtemplate',
            name='redirect_url',
            field=models.TextField(blank=True, null=True, verbose_name='redirect URL'),
        ),
        migrations.AddField(
            model_name='pushnotificationmessage',
            name='redirect_url',
            field=models.TextField(blank=True, null=True, verbose_name='redirect URL'),
        ),
    ]
