# -*- coding: utf-8 -*-
# Generated by Django 1.11.26 on 2020-02-25 19:11
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ('pymess', '0015_auto_20200110_0904'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='dialermessagerelatedobject',
            name='object_id_int',
        ),
        migrations.RemoveField(
            model_name='dialertemplatedisallowedobject',
            name='object_id_int',
        ),
        migrations.RemoveField(
            model_name='emailrelatedobject',
            name='object_id_int',
        ),
        migrations.RemoveField(
            model_name='emailtemplatedisallowedobject',
            name='object_id_int',
        ),
        migrations.RemoveField(
            model_name='outputsmsrelatedobject',
            name='object_id_int',
        ),
        migrations.RemoveField(
            model_name='pushnotificationmessagerelatedobject',
            name='object_id_int',
        ),
        migrations.RemoveField(
            model_name='smstemplatedisallowedobject',
            name='object_id_int',
        ),
        migrations.AddField(
            model_name='dialermessage',
            name='number_of_send_attempts',
            field=models.PositiveIntegerField(default=0, verbose_name='number of send attempts'),
        ),
        migrations.AddField(
            model_name='outputsmsmessage',
            name='number_of_send_attempts',
            field=models.PositiveIntegerField(default=0, verbose_name='number of send attempts'),
        ),
        migrations.AddField(
            model_name='pushnotificationmessage',
            name='number_of_send_attempts',
            field=models.PositiveIntegerField(default=0, verbose_name='number of send attempts'),
        ),
        migrations.AlterField(
            model_name='dialermessage',
            name='recipient',
            field=models.CharField(db_index=True, max_length=20, verbose_name='recipient'),
        ),
        migrations.AlterField(
            model_name='dialermessage',
            name='state',
            field=models.IntegerField(
                choices=[(-1, 'waiting'), (0, 'not assigned'), (1, 'ready'), (2, 'rescheduled by dialer'),
                         (3, 'call in progress'), (4, 'hangup'), (5, 'done'), (6, 'rescheduled'),
                         (7, 'listened up complete message'), (8, 'listened up partial message'), (9, 'unreachable'),
                         (10, 'declined'), (11, 'unanswered'), (12, 'unanswered - hangup by dialer'),
                         (13, 'answered - hangup by customer'), (66, 'error'), (77, 'debug'),
                         (88, 'error essage was not sent')], editable=False, verbose_name='state'),
        ),
        migrations.AlterField(
            model_name='dialermessagerelatedobject',
            name='object_id',
            field=models.TextField(db_index=True, verbose_name='ID of the related object'),
        ),
        migrations.AlterField(
            model_name='dialertemplatedisallowedobject',
            name='object_id',
            field=models.TextField(db_index=True, verbose_name='ID of the related object'),
        ),
        migrations.AlterField(
            model_name='emailmessage',
            name='recipient',
            field=models.EmailField(db_index=True, max_length=254, verbose_name='recipient'),
        ),
        migrations.AlterField(
            model_name='emailmessage',
            name='state',
            field=models.IntegerField(
                choices=[(1, 'waiting'), (2, 'sending'), (3, 'sent'), (4, 'error essage was not sent'), (5, 'debug')],
                editable=False, verbose_name='state'),
        ),
        migrations.AlterField(
            model_name='emailrelatedobject',
            name='object_id',
            field=models.TextField(db_index=True, verbose_name='ID of the related object'),
        ),
        migrations.AlterField(
            model_name='emailtemplatedisallowedobject',
            name='object_id',
            field=models.TextField(db_index=True, verbose_name='ID of the related object'),
        ),
        migrations.AlterField(
            model_name='outputsmsmessage',
            name='recipient',
            field=models.CharField(db_index=True, max_length=20, verbose_name='recipient'),
        ),
        migrations.AlterField(
            model_name='outputsmsmessage',
            name='state',
            field=models.IntegerField(
                choices=[(1, 'waiting'), (2, 'unknown'), (3, 'sending'), (4, 'sent'), (5, 'error'), (6, 'debug'),
                         (7, 'delivered'), (8, 'error message was not sent')], editable=False, verbose_name='state'),
        ),
        migrations.AlterField(
            model_name='outputsmsrelatedobject',
            name='object_id',
            field=models.TextField(db_index=True, verbose_name='ID of the related object'),
        ),
        migrations.AlterField(
            model_name='pushnotificationmessage',
            name='recipient',
            field=models.CharField(db_index=True, max_length=20, verbose_name='recipient'),
        ),
        migrations.AlterField(
            model_name='pushnotificationmessage',
            name='state',
            field=models.PositiveIntegerField(
                choices=[(1, 'waiting'), (2, 'sent'), (3, 'error essage was not sent'), (4, 'debug')], editable=False,
                verbose_name='state'),
        ),
        migrations.AlterField(
            model_name='pushnotificationmessagerelatedobject',
            name='object_id',
            field=models.TextField(db_index=True, verbose_name='ID of the related object'),
        ),
        migrations.AlterField(
            model_name='smstemplatedisallowedobject',
            name='object_id',
            field=models.TextField(db_index=True, verbose_name='ID of the related object'),
        ),
    ]
